@@ -146,7 +146,7 @@ class PrintVisitor(OperationVisitor):
                 operation.pads.tolist(),
             )
         )
-    
+
     def visit_ConvTranspose(self, operation: operations.ConvTranspose) -> None:
         self.generic_visit(operation)
         self.print_op_id(operation)
@@ -161,6 +161,13 @@ class PrintVisitor(OperationVisitor):
             )
         )
 
+    def visit_Div(self, operation: operations.Div) -> None:
+        self.generic_visit(operation)
+        self.print_op_id(operation)
+        print(
+            "Div(%s, %s)" % (self.get_op_id(operation.a), self.get_op_id(operation.b))
+        )
+
     def visit_Dropout(self, operation: operations.Dropout) -> None:
         self.generic_visit(operation)
         self.print_op_id(operation)
@@ -313,6 +320,13 @@ class PrintVisitor(OperationVisitor):
         self.print_op_id(operation)
         print("Softmax(%s, axis=%s)" % (self.get_op_id(operation.x), operation.axis))
 
+    def visit_Sub(self, operation: operations.Sub) -> None:
+        self.generic_visit(operation)
+        self.print_op_id(operation)
+        print(
+            "Sub(%s, %s)" % (self.get_op_id(operation.a), self.get_op_id(operation.b))
+        )
+
     def visit_Tanh(self, operation: operations.Tanh) -> None:
         self.generic_visit(operation)
         self.print_op_id(operation)
